Changelog
=========

0.0.3 (2015-02-12)
------------------

- Adds OSX detection
- Adds port option for postgres backend
- Changes working directory of postgres subprocess command to /tmp


0.0.2 (2014-11-25)
------------------

- Update how args are parsed to allow use from call_command


0.0.1 (2013-09-27)
------------------

- All important fix-the-bladdy-packaging release


0.0.0 (2013-09-27)
------------------

- Initial Release
